import type { Meta, StoryObj } from '@storybook/vue3';

import Button from '@/components/Button/Button.vue';
import { InputSize, ButtonType } from '@/types';

// More on how to set up stories at: https://storybook.js.org/docs/7.0/vue/writing-stories/introduction
const meta: Meta<typeof Button> = {
  title: 'Components/Button',
  component: Button,
  // This component will have an automatically generated docsPage entry: https://storybook.js.org/docs/7.0/vue/writing-docs/docs-page
  tags: ['autodocs'],
  argTypes: {
    // size: { control: 'select', options: ['small', 'medium', 'large'] },
    // backgroundColor: { control: 'color' },
    // onClick: { action: 'clicked' },
    type: {
      control: 'select',
      options: Object.values(ButtonType),
    },
    size: {
      control: 'select',
      options: Object.values(InputSize),
    },
  },
  args: {
    label: 'Button text',
  }, // default value
};

export default meta;
type Story = StoryObj<typeof Button>;
/*
 *👇 Render functions are a framework specific feature to allow you control on how the component renders.
 * See https://storybook.js.org/docs/7.0/vue/api/csf
 * to learn how to use render functions.
 */

export const Default: Story = {};

export const Small: Story = {
  args: {
    size: InputSize.SMALL,
  },
};

export const Medium: Story = {
  args: {
    size: InputSize.MEDIUM,
  },
};

export const Large: Story = {
  args: {
    size: InputSize.LARGE,
  },
};

export const ExtraLarge: Story = {
  args: {
    size: InputSize.EXTRALARGE,
  },
};

export const OutlineDefault: Story = {
  args: {
    outline: true,
  },
};

export const LinkButton: Story = {
  args: {
    type: ButtonType.LINK,
  },
};

export const Info: Story = {
  args: {
    type: ButtonType.INFO,
  },
};

export const InfoOutline: Story = {
  args: {
    type: ButtonType.INFO,
    outline: true,
  },
};

export const Primary: Story = {
  args: {
    type: ButtonType.PRIMARY,
  },
};

export const PrimaryOutline: Story = {
  args: {
    type: ButtonType.PRIMARY,
    outline: true,
  },
};

export const Secondary: Story = {
  args: {
    type: ButtonType.SECONDARY,
  },
};

export const SecondaryOutline: Story = {
  args: {
    type: ButtonType.SECONDARY,
    outline: true,
  },
};

export const Warning: Story = {
  args: {
    type: ButtonType.WARNING,
  },
};

export const WarningOutline: Story = {
  args: {
    type: ButtonType.WARNING,
    outline: true,
  },
};
