import { CheckboxType } from '@/types';
import type { Meta, StoryObj } from '@storybook/vue3';
import { ref } from 'vue';
import Checkbox from '../Checkbox.vue';

const meta: Meta<typeof Checkbox> = {
  title: 'Components/Checkbox',
  component: Checkbox,
  tags: ['autodocs'],
  args: {
    modelValue: true,
  },
  argTypes: {
    type: {
      control: 'select',
      options: Object.values(CheckboxType),
    },
  },
};

export default meta;

type Story = StoryObj<typeof Checkbox>;

export const Default: Story = {};
export const Primary: Story = {
  args: {
    type: CheckboxType.PRIMARY,
  },
};

export const Secondary: Story = {
  args: {
    type: CheckboxType.SECONDARY,
  },
};

export const DefaultWithLabel: Story = {
  args: {
    label: 'Checkbox label',
  },
};

export const PrimaryWithLabel: Story = {
  args: {
    type: CheckboxType.PRIMARY,
    label: 'Checkbox label',
  },
};

export const SecondaryWithLabel: Story = {
  args: {
    type: CheckboxType.SECONDARY,
    label: 'Checkbox label',
  },
};

export const DefaultRounded: Story = {
  args: {
    rounded: true,
  },
};

export const DefaultRoundedWithLabel: Story = {
  args: {
    rounded: true,
    label: 'Checkbox label',
  },
};

export const PrimaryRounded: Story = {
  args: {
    rounded: true,
    type: CheckboxType.PRIMARY,
  },
};

export const PrimaryRoundedWithLabel: Story = {
  args: {
    ...PrimaryRounded.args,
    label: 'Checkbox label',
  },
};

export const SecondaryRounded: Story = {
  args: {
    rounded: true,
    type: CheckboxType.SECONDARY,
  },
};

export const SecondaryRoundedWithLabel: Story = {
  args: {
    ...SecondaryRounded.args,
    label: 'Checkbox label',
  },
};

export const TestVModel: Story = {
  render: () => ({
    components: { Checkbox },
    setup() {
      return {
        checked: ref(true),
        label: 'Checkbox label',
      };
    },
    template: `
      v-model: {{ checked }}
      <Checkbox v-model="checked" :label="label"></Checkbox>
    `,
  }),
};
