import { InputSize } from '@/types';
import type { Meta, StoryObj } from '@storybook/vue3';
import Input from '../Input.vue';

const meta: Meta<typeof Input> = {
  title: 'Components/Input',
  component: Input,
  tags: ['autodocs'],
  args: {
    placeholder: 'Enter your name',
  },
  argTypes: {
    size: {
      control: 'select',
      options: Object.values(InputSize),
    },
  },
};

export default meta;

type Story = StoryObj<typeof Input>;

export const Default: Story = {};

export const WithLabel: Story = {
  args: {
    label: 'Input label',
  },
};

export const WithPlaceholder: Story = {
  args: {
    placeholder: 'Enter your name',
  },
};

export const WithPlaceholderAndLabel: Story = {
  args: {
    ...WithLabel.args,
    ...WithPlaceholder.args,
  },
};

export const SmallSize: Story = {
  args: {
    size: InputSize.SMALL,
  },
};

export const MediumSize: Story = {
  args: {
    size: InputSize.MEDIUM,
  },
};

export const LargeSize: Story = {
  args: {
    size: InputSize.LARGE,
  },
};

export const ExtraLargeSize: Story = {
  args: {
    size: InputSize.EXTRALARGE,
  },
};

export const Rounded: Story = {
  args: {
    rounded: true,
  },
};

export const RoundedAndLabel: Story = {
  args: {
    rounded: true,
    label: 'First name',
  },
};

export const RoundedLabelAndPlaceholder: Story = {
  args: {
    rounded: true,
    label: 'First name',
    placeholder: 'Enter your first name',
  },
};

export const Inline: Story = {
  args: {
    inline: true,
    label: 'First name',
    placeholder: 'Enter your name',
    rounded: true,
  },
};
