import { CheckboxType } from '@/types';
import type { Meta, StoryObj } from '@storybook/vue3';
import { ref } from 'vue';
import Radio from '../Radio.vue';

const meta: Meta<typeof Radio> = {
  title: 'Components/Radio',
  component: Radio,
  tags: ['autodocs'],
  args: {
    value: '1',
  },
  argTypes: {
    type: {
      control: 'select',
      options: Object.values(CheckboxType),
    },
    value: {
      control: 'text',
    },
  },
};

export default meta;

type Story = StoryObj<typeof Radio>;

export const Default: Story = {};
export const Primary: Story = {
  args: {
    type: CheckboxType.PRIMARY,
  },
};

export const Secondary: Story = {
  args: {
    type: CheckboxType.SECONDARY,
  },
};

export const DefaultWithLabel: Story = {
  args: {
    label: 'Radio label',
  },
};

export const PrimaryWithLabel: Story = {
  args: {
    type: CheckboxType.PRIMARY,
    label: 'Radio label',
  },
};

export const SecondaryWithLabel: Story = {
  args: {
    type: CheckboxType.SECONDARY,
    label: 'Radio label',
  },
};

export const TestVModel: Story = {
  render: (args) => ({
    components: { Radio },
    setup() {
      return {
        model: ref('vuejs'),
        ...args,
      };
    },
    template: `
      <div>v-model: {{ model }}</div>
      <div class="bg-slate-500 text-on-primary p-3 mb-2 rounded-md">Choose your favourite</div>
      <Radio v-model="model" value="vuejs" inline label="Vue JS"></Radio>
      <Radio v-model="model" value="reactjs" inline label="React JS"></Radio>
      <Radio v-model="model" value="angular" inline label="Angular JS"></Radio>
    `,
  }),
};
