import { CheckboxType } from '@/types';
import type { Meta, StoryObj } from '@storybook/vue3';
import { ref } from 'vue';
import Switch from '../Switch.vue';

const meta: Meta<typeof Switch> = {
  title: 'Components/Switch',
  component: Switch,
  tags: ['autodocs'],
  args: {
    modelValue: true,
  },
  argTypes: {
    type: {
      control: 'select',
      options: Object.values(CheckboxType),
    },
  },
};

export default meta;

type Story = StoryObj<typeof Switch>;

export const Default: Story = {};
export const Primary: Story = {
  args: {
    type: CheckboxType.PRIMARY,
  },
};

export const Secondary: Story = {
  args: {
    type: CheckboxType.SECONDARY,
  },
};

export const DefaultWithLabel: Story = {
  args: {
    label: 'Checkbox label',
  },
};

export const PrimaryWithLabel: Story = {
  args: {
    type: CheckboxType.PRIMARY,
    label: 'Checkbox label',
  },
};

export const SecondaryWithLabel: Story = {
  args: {
    type: CheckboxType.SECONDARY,
    label: 'Checkbox label',
  },
};

export const TestVModel: Story = {
  render: () => ({
    components: { Switch },
    setup() {
      return {
        checked: ref(true),
        label: 'Checkbox label',
      };
    },
    template: `
      <div>v-model: {{ checked }}</div>
      <Switch v-model="checked" :label="label"></Switch>
    `,
  }),
};
