import { AspectRatio } from '@/types';
import type { Meta, StoryObj } from '@storybook/vue3';
import Thumbnail from '../Thumbnail.vue';

const meta: Meta<typeof Thumbnail> = {
  title: 'Components/Thumbnail',
  component: Thumbnail,
  tags: ['autodocs'],
  args: {
    ratio: AspectRatio.AUTO,
    caption: 'MacBook Pro 13" with M2 CHIP',
    src: 'https://placehold.co/600x400/EEE/31343C',
  },
  argTypes: {
    ratio: {
      control: 'select',
      options: Object.values(AspectRatio),
    },
  },
};

export default meta;

type Story = StoryObj<typeof Thumbnail>;

export const Default: Story = {};

export const Square: Story = {
  args: {
    ratio: AspectRatio.SQUARE,
  },
};

export const Wide: Story = {
  args: {
    ratio: AspectRatio.WIDE,
  },
};

export const FullWidth: Story = {
  args: {
    fullWidth: true,
  },
};

export const FullWidthSquare: Story = {
  args: {
    fullWidth: true,
    ratio: AspectRatio.SQUARE,
  },
};

export const FullWidthWide: Story = {
  args: {
    fullWidth: true,
    ratio: AspectRatio.WIDE,
  },
};

export const WithCaption: Story = {
  args: {
    caption:
      'MacBook Pro 13" with M2 CHIP Multiple line caption, line clamp after 2 lines of text. This text will be shown in max 2 lines of text.',
  },
};

export const WithoutCaption: Story = {
  args: {
    caption: '',
  },
};

export const Rounded: Story = {
  args: {
    rounded: true,
  },
};
